@@ -38,40 +38,22 @@ class _Loadscreen(_HtmlElement):
             _HtmlElement(
                 "style",
                 {},
-                """
-                body {
-                    margin: 0;
-                    padding: 0;
-                    box-sizing: border-box;
-                    width: 100vw;
-                    height: 100vh;
-                }
-                .container {
-                    width: 100%;
-                    height: 100%;
-                    display: flex;
-                    flex-direction: column;
-                    align-items: center;
-                    justify-content: center;
-                    position: fixed;
-                }
-                .loader {
-                    border: 12px solid lightgray;
-                    border-radius: 50%;
-                    border-top: 12px solid skyblue;
-                    width: 100px;
-                    height: 100px;
-                    animation: spin 1s linear infinite;
-                }
-                @keyframes spin{
-                    0%{
-                        transform: rotate(0deg);
-                    }
-                    100%{
-                        transform: rotate(360deg);
-                    }
-                }
-                """,
+                " ".join(
+                    f"{selector}{{"
+                    + "".join(
+                        name
+                        + (
+                            "{{{}}}".format(
+                                "".join(f"{n}:{v};" for n, v in value.items())
+                            )
+                            if isinstance(value, dict)
+                            else f":{value};"
+                        )
+                        for name, value in props.items()
+                    )
+                    + "}"
+                    for selector, props in self._style.items()
+                ),
             ),
             _HtmlElement(
                 "div",
@@ -81,7 +63,44 @@ class _Loadscreen(_HtmlElement):
                     {"class": "loader"},
                 ),
             ),
-        ),
+        )
+
+    @property
+    def _style(self):
+        return {
+            "body": {
+                "margin": "0",
+                "padding": "0",
+                "box-sizing": "border-box",
+                "width": "100vw",
+                "height": "100vh",
+            },
+            ".container": {
+                "width": "100%",
+                "height": "100%",
+                "display": "flex",
+                "flex-direction": "column",
+                "align-items": "center",
+                "justify-content": "center",
+                "position": "fixed",
+            },
+            ".loader": {
+                "border": "12px solid lightgray",
+                "border-radius": "50%",
+                "border-top": "12px solid skyblue",
+                "width": "100px",
+                "height": "100px",
+                "animation": "spin 1s linear infinite",
+            },
+            "@keyframes spin": {
+                "0%": {
+                    "transform": "rotate(0deg)",
+                },
+                "100%": {
+                    "transform": "rotate(360deg)",
+                },
+            },
+        }
 
 
 def _load_scripts(scripts: list[tuple[dict[str, str], str | None]]):
@@ -106,28 +125,28 @@ def generate_html(
         (
             {
                 "type": "text/javascript",
-                "src": f"{base}_scripts/brython.js",
+                "src": f"{base}scripts/brython.js",
             },
             None,
         ),
         (
             {
                 "type": "text/javascript",
-                "src": f"{base}_scripts/brython_stdlib.js",
+                "src": f"{base}scripts/brython_stdlib.js",
             },
             None,
         ),
         (
             {
                 "type": "text/javascript",
-                "src": f"{base}_scripts/webcompy.brython.js",
+                "src": f"{base}scripts/webcompy.brython.js",
             },
             None,
         ),
         (
             {
                 "type": "text/javascript",
-                "src": f"{base}_scripts/{config.app_package}.brython.js",
+                "src": f"{base}scripts/{config.app_package}.brython.js",
             },
             None,
         ),
@@ -136,24 +155,28 @@ def generate_html(
     scripts.append(
         (
             {"type": "text/python"},
-            """
+            strip_multiline_text(
+                """
                 from {app_package}.bootstrap import app
                 app.__component__.render()
-            """.format(
-                app_package=config.app_package
-            ),
+                """.format(
+                    app_package=config.app_package
+                )
+            ).strip(),
         )
     )
     if dev_mode:
         scripts.append(
             (
                 {"type": "text/javascript"},
-                """
+                strip_multiline_text(
+                    """
                     var stream= new EventSource('{base}_webcompy_reload');
                     stream.addEventListener('error', (e) => window.location.reload());
-                """.format(
-                    base=base
-                ),
+                    """.format(
+                        base=base
+                    )
+                ).strip(),
             )
         )
     if title := app.__head__.get("title"):
